@@ -8,14 +8,13 @@ from django.utils.datastructures import SortedDict
 def _get_boilerplate_source_dir(boilerplate_name):
     if boilerplate_name is None:
         return 'static'
-    return 'static_for_boilerplates/{}'.format(settings.ALDRYN_BOILERPLATE_NAME)
+    return 'boilerplates/{}/static'.format(settings.ALDRYN_BOILERPLATE_NAME)
 
 
 class BoilerplateAppStaticStorage(django.contrib.staticfiles.storage.AppStaticStorage):
     """
     A file system storage backend that takes an app module and works
-    for the ``static_for_boilerplates`` directory of it and add the currently
-    configured boilerplate to the path.
+    for the ``boilerplates/<my-boilerplate-name>/static`` directory inside the app.
     """
     source_dir = _get_boilerplate_source_dir(settings.ALDRYN_BOILERPLATE_NAME)
 
